<?php

if(isset($_POST['test-settings'])) {

    require_once plugin_dir_path(dirname(__DIR__)) . 'includes/settings.php';

    validate_leadifly_options($_POST['api-options']);
}

if (isset($_GET['oauth_token']) && isset($_GET['oauth_verifier'])) {
    $options = get_option('leadifly_options');
    $options['aweber_request_token'] = sanitize_text_field($_GET['oauth_token']);
    $options['aweber_code'] = sanitize_text_field($_GET['oauth_verifier']);
    update_option('leadifly_options', $options);
}

?>

<div class="wrap">
    <h2><?php esc_attr_e( 'Leadifly Settings', 'WpAdminStyle' ); ?></h2>
    <?php
    if (isset($_GET['tab'])) {
        $active_tab = $_GET['tab'];
    } else {
        $active_tab = 'general_options';
    }

    function is_tab_active($tab, $active_tab)
    {
        if ($active_tab == $tab)
            return 'nav-tab-active';
    }

    ?>

    <h2 class="nav-tab-wrapper">
        <a href="?page=leadify_settings&tab=general_options" class="nav-tab <?=is_tab_active('general_options', $active_tab)?>">Facebook</a>
        <a href="?page=leadify_settings&tab=mailchimp_options" class="nav-tab <?=is_tab_active('mailchimp_options', $active_tab)?>">MailChimp</a>
        <a href="?page=leadify_settings&tab=activecampaign_options" class="nav-tab <?=is_tab_active('activecampaign_options', $active_tab)?>">Active Campaign</a>
        <a href="?page=leadify_settings&tab=getresponse_options" class="nav-tab <?=is_tab_active('getresponse_options', $active_tab)?>">Get Response</a>
        <a href="?page=leadify_settings&tab=sendlane_options" class="nav-tab <?=is_tab_active('sendlane_options', $active_tab)?>">Sendlane</a>
        <a href="?page=leadify_settings&tab=aweber_options" class="nav-tab <?=is_tab_active('aweber_options', $active_tab)?>">Aweber</a>
    </h2>
    <?php
    $options = get_option('leadifly_options');
        switch ($active_tab) {
            case 'general_options':
                if (!isset($options['facebook_valid']) || $options['facebook_valid'] != 1) {
                    print_error('Wrong Facebook App credentials used!');
                }
                break;
            case 'mailchimp_options':
                if (!isset($options['mailchimp_valid']) || $options['mailchimp_valid'] != 1) {
                    print_error('Wrong Mailchimp App Key or List ID used!');
                }
                break;
            case 'activecampaign_options':
                if (!isset($options['activecampaign_valid']) || $options['activecampaign_valid'] != 1) {
                    print_error('Wrong Active Campaign API Key or List ID used!');
                }
                break;
            case 'getresponse_options':
                if (!isset($options['getresponse_valid']) || $options['getresponse_valid'] != 1) {
                    print_error('Wrong Get Response API Key or Campaign ID used!');
                }
                break;
            case 'sendlane_options':
                if (!isset($options['sendlane_valid']) || $options['sendlane_valid'] != 1) {
                    print_error('Wrong Sendlane API Key, Hash Key or List ID!');
                }
                break;
            case 'aweber_options':
                if (!isset($options['aweber_valid']) || $options['aweber_valid'] != 1) {
                    print_error('Wrong Aweber credentials!');
                }
                break;
        }
    ?>
    <div class="leadify-settings">
        <form action="options.php" method="post" id="leadify-options-form">
            <?php
            settings_fields('leadifly_options');
            ?>

            <span style="<?=get_display_style('general_options', $active_tab)?>"><?php do_settings_sections('leadifly_general') ?></span>
            <span style="<?=get_display_style('mailchimp_options', $active_tab)?>"><?php do_settings_sections('leadifly_mailchimp') ?></span>
            <span style="<?=get_display_style('activecampaign_options', $active_tab)?>"><?php do_settings_sections('leadifly_activecampaign') ?></span>
            <span style="<?=get_display_style('getresponse_options', $active_tab)?>"><?php do_settings_sections('leadifly_getresponse') ?></span>
            <span style="<?=get_display_style('sendlane_options', $active_tab)?>"><?php do_settings_sections('leadifly_sendlane') ?></span>
            <span style="<?=get_display_style('aweber_options', $active_tab)?>"><?php do_settings_sections('leadifly_aweber') ?></span>

            <?php
            function get_display_style($section, $current)
            {
                if ($section != $current) {
                    return 'display:none;';
                }

                $_SESSION['current_options'] = $current;
                return '';
            }

            function get_validate_button_text($current)
            {
                return 'Validate Settings (required)';
            }

            function strip_options_word($current)
            {
                $start = strpos($current, '_options');

                $api = substr($current, 0, $start);

                if ($api == 'general') $api = 'facebook';

                return $api;
            }

            submit_button();
            ?>
        </form>

        <?php
        $current_api = strip_options_word($_SESSION['current_options']);

        if (!isset($options[$current_api . '_valid']) || $options[$current_api . '_valid'] == 0) :
        ?>
        <form method="post" name="validate-credentials">
            <span id="validate-button">
                <input id="test-settings" name="test-settings" type="submit" value="<?=get_validate_button_text($_SESSION['current_options'])?>" class="button">
                <input type="hidden" name="api-options" value="<?=$current_api?>">
            </span>
        </form>
        <?php
        endif;
        ?>
    </div>
</div>
<?php

function print_error($text)
{
    echo '<div class="notice notice-error"><p>' . $text . '</p></div>';
}
