<?php

require_once plugin_dir_path(__DIR__) . 'packages/Aweber/aweber_api.php';

class LeadiflyAweber
{
    private $consumer_key;
    private $consumer_secret;
    private $list_id;
    private $aweber;
    public $options;
    public $valid;

    public function __construct()
    {
        $leadify_option = get_option('leadifly_options');
        $this->options = $leadify_option;

        if (isset($leadify_option['aweber_consumer_key']) &&
            $leadify_option['aweber_consumer_key'] != '' &&
            isset($leadify_option['aweber_list_id']) &&
            $leadify_option['aweber_list_id'] != '' &&
            isset($leadify_option['aweber_consumer_secret']) &&
            $leadify_option['aweber_consumer_secret'] != ''
        ) {
            $this->consumer_key = $leadify_option['aweber_consumer_key'];
            $this->consumer_secret = $leadify_option['aweber_consumer_secret'];
            $this->list_id = $leadify_option['aweber_list_id'];
        }

        if (isset($this->options['aweber_valid']))
            $this->valid = $this->options['aweber_valid'];

        $this->aweber = new AWeberAPI($this->consumer_key, $this->consumer_secret);
    }

    public function testAuth()
    {
        try {
            $this->aweber->getRequestToken('oob');
            $this->options['aweber_valid'] = 1;
            update_option('leadifly_options', $this->options);
        } catch (Exception $exception) {
            $this->options['aweber_valid'] = 0;
            update_option('leadifly_options', $this->options);
        }
    }

    public function getAuthorizeLink()
    {
        $callbackUrl = admin_url() . 'admin.php?page=leadify_settings&tab=aweber_options';
        list($requestToken, $tokenSecret) = $this->aweber->getRequestToken($callbackUrl);

        $this->options['aweber_request_token'] = $requestToken;
        $this->options['aweber_token_secret'] = $tokenSecret;
        update_option('leadifly_options', $this->options);

        return $this->aweber->getAuthorizeUrl();
    }

    public function authorizeCode()
    {
        $this->aweber->user->requestToken = $this->options['aweber_request_token'];
        $this->aweber->user->tokenSecret = $this->options['aweber_token_secret'];
        $this->aweber->user->verifier = $this->options['aweber_code'];
        try {
            list($access_token, $access_secret) = $this->aweber->getAccessToken();
            $this->options['aweber_access_token'] = $access_token;
            $this->options['aweber_access_secret'] = $access_secret;
            $this->options['aweber_code_authorized'] = 1;
            update_option('leadifly_options', $this->options);
            $_SESSION['aweber_code_authorized'] = 1;
        } catch (Exception $e) {
            var_dump($e);
            $this->options['aweber_code_authorized'] = 0;
            update_option('leadifly_options', $this->options);
        }
    }

    public function addSubscriberToList($data)
    {
        $account = $this->aweber->getAccount($this->options['aweber_access_token'], $this->options['aweber_access_secret']);

        try {
            $listURL = '/accounts/' . $account->id . '/lists/' . $this->list_id;
            $list = $account->loadFromUrl($listURL);

            $params = array(
                'email' => $data['email'],
                'name' => $data['first_name'] . ' ' . $data['last_name']
            );
            $subscribers = $list->subscribers;
            $subscribers->create($params);

        } catch (AWeberAPIException $exc) {

        }
    }
}