<?php

class LeadiflyLinks {

    public static $link = 'leadifly_link';

    protected static $instance = null;
    protected static $installed = null;

    public static function installLinks() {
        if (is_null(self::$installed)) {
            $linkObject = new self();
            $linkObject->install();
            self::$installed = true;
        }
    }

    public function __construct()
    {
        add_action('init', array($this, 'register_link_post_type'));
        add_action('add_meta_boxes', array($this, 'add_link_meta_boxes'));
        add_action('save_post', array($this, 'save_link'));
        add_filter('manage_leadifly_link_posts_columns', array($this, 'add_leadifly_link_head'));
        add_action('manage_leadifly_link_posts_custom_column', array($this, 'add_leadifly_link_column'), 10 , 2);

        add_action('admin_post_nopriv_fb_callback', array($this, 'fb_callback'));//ToDo this wont work in admin logged in
        add_action('admin_post_fb_callback', array($this, 'fb_callback'));
    }

    public function register_link_post_type()
    {

        $args = array(
            'labels' => array(
                'name' => 'Leadifly Links',
                'singular_name' => 'Leadifly Link',
                'edit_item' => 'Edit Link',
                'add_new' => 'Add Link',
                'new_item' => 'New Link',
                'add_new_item' => 'Add New Link',
                'search_items' => 'Search Links'
            ),
            'description' => 'Leadify link',
            'supports' => array(
                'title',
            ),
            'hierarchical' => false,
            'public' => true,
            'show_ui' => true,
            'show_in_menu' => false,
            'show_in_nav_menus' => false,
            'show_in_admin_bar' => false,
            'menu_position' => 5,
            'menu_icon' => '',
            'can_export' => false,
            'has_archive' => false,
            'exclude_from_search' => false,
            'publicly_queryable' => true,
            'capability_type' => 'post'
        );

        register_post_type(self::$link, $args);
    }

    public function add_link_meta_boxes()
    {
        add_meta_box('leadifly-meta-link', 'Url', array($this, 'print_link_url_input'), 'leadifly_link');
    }

    public function print_link_url_input($post)
    {
        wp_nonce_field('save_leadifly_link', 'leadifly_nonce');
        $leadifly_link = get_post_meta($post->ID, 'leadifly-meta-link', true);
        echo ('<input type="url" style="width:100%;" class="regular-text"   id="leadifly-meta-link" name="leadifly-meta-link" value="'.esc_url( $leadifly_link ).'" required /> ');
    }

    public function save_link($post_id)
    {
        $post_type = get_post_type($post_id);

        if ($post_type != self::$link) return;

        if (isset($_POST['leadifly_nonce'])) {
            if (!wp_verify_nonce($_POST['leadifly_nonce'], 'save_leadifly_link')) {
                return;
            }
        } else { return; }

        if (isset($_POST['leadifly-meta-link'])) {

            if (filter_var($_POST['leadifly-meta-link'], FILTER_VALIDATE_URL) === FALSE) {
                return;
            }

            update_post_meta($post_id, 'leadifly-meta-link', esc_url($_POST['leadifly-meta-link']));
        }
    }

    public function add_leadifly_link_head($defaults)
    {
        $new = array();
        foreach ($defaults as $key => $title) {
            if ($key == 'date')
                $new['leadifly_link'] = 'URL';
            $new[$key] = $title;
        }
        return $new;
    }

    public function add_leadifly_link_column($column_name, $post_ID)
    {
         if ($column_name == 'leadifly_link') {
                $url = get_post_meta($post_ID, 'leadifly-meta-link', true);

                if (isset($url) && !empty($url)) {
                    echo $url;
                } else {
                    echo '-';
                }
            }
    }

    public function fb_callback()
    {
        require_once plugin_dir_path(__FILE__) . 'fb-callback.php';
    }
}