<?php

class LeadiflyNotifications {

    public static $notification = 'leadifly_notif';

    public function __construct()
    {
        add_action('init', array($this, 'register_notification_post_type'));
        add_action('add_meta_boxes', array($this, 'add_notification_meta_boxes'));
        add_action('save_post', array($this, 'save_notification'));
        add_action('save_post', array($this, 'on_publish_post'), 10, 2);
        add_filter('manage_leadifly_notif_posts_columns', array($this, 'add_leadifly_notif_head'));
        add_action('manage_leadifly_notif_posts_custom_column', array($this, 'add_leadifly_notif_columns'), 10, 2);
    }

    public function register_notification_post_type()
    {
        $args = array(
            'labels' => array(
                'name' => 'Leadifly Notifications',
                'singular_name' => 'Leadifly Notification',
                'edit_item' => 'Edit Notification',
                'add_new' => 'New Notification',
                'new_item' => 'New Notification',
                'add_new_item' => 'Send New Notification',
                'search_items' => 'Search Notifications'
            ),
            'description' => 'Leadify notification',
            'hierarchical' => false,
            'public' => true,
            'supports' => array(
                'title'
            ),
            'show_ui' => true,
            'show_in_menu' => false,
            'show_in_nav_menus' => false,
            'show_in_admin_bar' => false,
            'menu_position' => 5,
            'menu_icon' => '',
            'can_export' => false,
            'has_archive' => false,
            'exclude_from_search' => false,
            'publicly_queryable' => true,
            'capability_type' => 'post',
            'capabilities' => array(

            )
        );

        register_post_type(self::$notification, $args);
    }

    public function add_notification_meta_boxes()
    {
        add_meta_box('leadifly-notif-content', 'Content', array($this, 'print_content_input'), 'leadifly_notif');
        add_meta_box('leadifly-notif-url', 'Url', array($this, 'print_url_input'), 'leadifly_notif');
    }

    public function print_content_input($post)
    {
        wp_nonce_field('save_leadifly_notification', 'leadifly_nonce');
        $leadifly_content = get_post_meta($post->ID, 'leadifly-notif-content', true);
        echo '<input type="text" style="width:100%;"  class="regular-text" id="leadifly-notif-content" name="leadifly-notif-content" required value="'.sanitize_text_field($leadifly_content).'">';
    }

    public function print_url_input($post)
    {
        wp_nonce_field('save_leadifly_notification', 'leadifly_nonce');
        $leadifly_link = get_post_meta($post->ID, 'leadifly-notif-url', true);
        echo ('<input type="url" style="width:100%;" class="regular-text"   id="leadifly-notif-url" name="leadifly-notif-url" value="'.esc_url( $leadifly_link ).'" required /> ');
    }

    public function save_notification($post_id)
    {
        $post_type = get_post_type($post_id);

        if ($post_type != self::$notification) return;

        if (isset($_POST['leadifly_nonce'])) {
            if (!wp_verify_nonce($_POST['leadifly_nonce'], 'save_leadifly_notification')) {
                return;
            }
        } else { return; }

        if (isset($_POST['leadifly-notif-content'])) {

            if (empty($_POST['leadifly-notif-content'])) {
                return;
            }

            update_post_meta($post_id, 'leadifly-notif-content', sanitize_text_field($_POST['leadifly-notif-content']));
        }

        if (isset($_POST['leadifly-notif-url'])) {

            if (filter_var($_POST['leadifly-notif-url'], FILTER_VALIDATE_URL) === FALSE) {
                return;
            }

            update_post_meta($post_id, 'leadifly-notif-url', esc_url($_POST['leadifly-notif-url']));
        }

    }

    public function on_publish_post( $post_id )
    {
        $post_type = get_post_type($post_id);

        if ($post_type != self::$notification) return;

        $content = get_post_meta($post_id, 'leadifly-notif-content', true);
        $url = get_post_meta($post_id, 'leadifly-notif-url', true);

        update_post_meta($post_id, 'leadifly-notif-status', 'pending');

        $this->sendFBNotification($content, $url, $post_id);

    }

    public function sendFBNotification($content, $url, $post_id)
    {
        require_once plugin_dir_path(__FILE__) . 'fb-api.php';

        $notification = new LeadiflyFBApi();
        $notification->sendPushNotification($content, $url, $post_id);
    }

    public function add_leadifly_notif_head($defaults)
    {
        $new = array();
        foreach ($defaults as $key => $title) {
            if ($key == 'date') {
                $new['leadifly_notif_content'] = 'Content';
                $new['leadifly_notif_url'] = 'Url';
                $new['leadifly_notif_status'] = 'Status';
                $new['leadifly_notif_counter'] = 'Recipients';
            }
            $new[$key] = $title;
        }
        return $new;
    }

    public function add_leadifly_notif_columns($column_name, $post_ID)
    {
        switch ($column_name) {
            case 'leadifly_notif_content':
                $url = get_post_meta($post_ID, 'leadifly-notif-content', true);
                echo $url;
                break;
            case 'leadifly_notif_url':
                $url = get_post_meta($post_ID, 'leadifly-notif-url', true);
                echo "<a href='{$url}' target='_blank'>{$url}</a>";
                break;
            case 'leadifly_notif_status':
                $status = get_post_meta($post_ID, 'leadifly-notif-status', true);
                echo $status;
                break;
            case 'leadifly_notif_counter':
                $counter = get_post_meta($post_ID, 'leadifly-notif-counter', true);
                echo $counter;
                break;
        }
    }
}