<?php

class LeadiflySubscribers {

    public static $subscriber_taxonomy = 'leadifly_subscriber_category';
    public static $subscriber = 'leadifly_subscriber';

    public function __construct()
    {
        add_action('init', array($this, 'register_subscriber_taxonomy'), 0);
        add_action('init', array($this, 'register_subscriber_post_type'));
        add_action('manage_leadifly_subscriber_posts_columns', array($this, 'add_leadifly_subscriber_head'));
        add_action('manage_leadifly_subscriber_posts_custom_column', array($this, 'add_leadifly_subscriber_columns'), 10, 2);
    }

    public function register_subscriber_taxonomy() {
        $args = array(
            'label' => 'Subscriber Category',
            'public' => true,
            'show_ui' => true,
            'show_in_menu' => true,
            'show_admin_column' => true,
            'query_var' => true,
            'hierarchical' => true,
            'rewrite' => array(
                'with_front' => true,
                'hierarchical' => true
            )
        );

        register_taxonomy(self::$subscriber_taxonomy, self::$subscriber, $args);

        $term = term_exists('Uncategorized', self::$subscriber_taxonomy);

        if (empty($term)) {
            $args = array(
                'slug' => 'uncategorized'
            );
            wp_insert_term('Uncategorized', self::$subscriber_taxonomy, $args);
        }
    }

    public function register_subscriber_post_type()
    {
        $args = array(
            'labels' => array(
                'name' => 'Leadifly Subscribers',
                'singular_name' => 'Leadifly Subscriber',
                'edit_item' => 'Edit Subscriber',
                'add_new' => 'Add Subscriber',
                'new_item' => 'New Subscriber',
                'add_new_item' => 'Add New Subscriber',
                'search_items' => 'Search Subscribers'
            ),
            'description' => 'Leadify subscriber',
            'supports' => array(
                'title'
            ),
            'taxonomies' => array(self::$subscriber_taxonomy),
            'hierarchical' => false,
            'public' => false,
            'show_ui' => true,
            'show_in_menu' => false,
            'show_in_nav_menus' => false,
            'show_in_admin_bar' => false,
            'menu_position' => 5,
            'menu_icon' => '',
            'can_export' => false,
            'has_archive' => false,
            'exclude_from_search' => false,
            'publicly_queryable' => false,
            'capability_type' => 'post',

        );

        register_post_type(self::$subscriber, $args);
    }

    public function create($args, $accessTokenLong)
    {
        $email = sanitize_email($args['email']);
        $firstName = sanitize_text_field($args['first_name']);
        $lastName = sanitize_text_field($args['last_name']);
        $fbId = sanitize_text_field($args['id']);
        $accessTokenLong = sanitize_text_field($accessTokenLong);

        $postId = wp_insert_post([
            'post_title' => $firstName . ' ' . $lastName,
            'post_status' => 'publish',
            'post_type' => 'leadifly_subscriber',
        ]);

        update_post_meta($postId, 'leadifly_subscriber_fb_id', $fbId);
        update_post_meta($postId, 'leadifly_subscriber_email', $email);
        update_post_meta($postId, 'leadifly_subscriber_first_name', $firstName);
        update_post_meta($postId, 'leadifly_subscriber_last_name', $lastName);
        update_post_meta($postId, 'leadifly_subscriber_access_token', $accessTokenLong);
    }

    public function add_leadifly_subscriber_head($defaults)
    {
        $new = array();
        foreach ($defaults as $key => $title) {
            if ($key == 'date') {
                $new['leadifly_subscriber_email'] = 'EMAIL';
                $new['leadifly_subscriber_fb_id'] = 'FB ID';
            }
            $new[$key] = $title;
        }
        return $new;
    }

    public function add_leadifly_subscriber_columns($column_name, $post_ID)
    {
        switch ($column_name) {
            case 'leadifly_subscriber_email':
                $url = get_post_meta($post_ID, 'leadifly_subscriber_email', true);
                echo $url;
                break;
            case 'leadifly_subscriber_fb_id':
                $id = get_post_meta($post_ID, 'leadifly_subscriber_fb_id', true);
                echo "<a href='https://facebook.com/{$id}' target='_blank'>{$id}</a>";
                break;
        }
    }

    public function checkIfSubscriberExists($fbId, $email)
    {
        $query = array(
            'post_type' => 'leadifly_subscriber',
            'post_status' => array('publish'),
            'meta_query' => array(
                'relation' => 'OR',
                array(
                    'key' => 'leadifly_subscriber_fb_id',
                    'value' => $fbId,
                    'compare' => '='
                ),
                array(
                    'key' => 'leadifly_subscriber_email',
                    'value' => $email,
                    'compare' => '='
                )
            )
        );

        $subscribers = new WP_Query($query);

        if ($subscribers->have_posts()) {

            return true;
        }

        return false;
    }
}