<?php

require_once plugin_dir_path(__FILE__) . 'packages/Facebook/autoload.php';

use Facebook\Exceptions\FacebookResponseException;
use Facebook\Exceptions\FacebookSDKException;
use Facebook\Facebook;

class LeadiflyFBApi {

    protected $fb;
    protected $app_id;
    protected $app_secret;
    protected $version;
    protected $options;

    public function __construct()
    {
        $this->version = 'v2.9';
        $this->set_fb();
    }

    public function set_fb()
    {
        $leadify_option = get_option('leadifly_options');
        $this->options = $leadify_option;

        if (
            isset($leadify_option['fb_app_id']) &&
            $leadify_option['fb_app_id'] != '' &&
            isset($leadify_option['fb_app_secret']) &&
            $leadify_option['fb_app_secret'] != ''
        ) {
            $this->app_id = $leadify_option['fb_app_id'];
            $this->app_secret = $leadify_option['fb_app_secret'];
            $this->fb = new Facebook([
                'app_id' => $this->app_id,
                'app_secret' => $this->app_secret,
                'default_graph_version' => $this->version,
            ]);
        } else {
            $leadify_option['facebook_valid'] = 0;
            update_option('leadifly_options', $leadify_option);
        }
    }

    public function getApplicationToken()
    {
        $url = "https://graph.facebook.com/" . $this->version . "/oauth/access_token?client_id=" . $this->app_id . "&client_secret=" . $this->app_secret . "&grant_type=client_credentials";
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        $str = curl_exec($ch);
        curl_close($ch);

        $tokenObject = json_decode($str);

        if (isset($tokenObject->access_token)) {
            $this->options['facebook_valid'] = 1;
            $this->options['fb_app_token'] = $tokenObject->access_token;
            update_option('leadifly_options', $this->options);
            return $tokenObject->access_token;
        }

        $this->options['facebook_valid'] = 0;
        update_option('leadifly_options', $this->options);
        return false;
    }

    public function sendPushNotification($content, $url, $notification_id)
    {
        $access_token = '';
        if (isset($this->options['fb_app_token'])) {
            $access_token = $this->options['fb_app_token'];
        }

        if (empty($access_token) || $access_token == '') {
            $access_token = $this->getApplicationToken();
        }

        $param = [
            'access_token' => $access_token,
            'template' => $content,
            'href' => '?url=' . urlencode($url),
            'type'=>'generic'
        ];

        $query = array(
            'post_type' => 'leadifly_subscriber',
            'meta_query' => array(
                array(
                    'key' => 'leadifly_subscriber_fb_id',
                    'value' => '',
                    'compare' => '!='
                )
            )

        );

        $loop = new WP_Query($query);
        $this->updateStatus($notification_id, 'sending');
        $counter = 0;

        while ($loop->have_posts()) {

            $loop->the_post();

            try {
                $fb_id = get_post_meta(get_the_ID(), 'leadifly_subscriber_fb_id', true);
                $endpoint = $fb_id . '/notifications';
                $notification = $this->fb->request('post', $endpoint, $param);
                $this->fb->getClient()->sendRequest($notification);
                $counter++;
                update_post_meta($notification_id, 'leadifly-notif-counter', $counter);
            } catch (FacebookResponseException $e) {
                //$this->updateToErrorStatus($post_id);
                return $e->getResponseData();
            } catch (FacebookSDKException $e) {
                //$this->updateToErrorStatus($post_id);
                return $e->getMessage();
            } catch (Exception $exception) {
                //$this->updateToErrorStatus($post_id);
            }

        }

        update_post_meta($notification_id, 'leadifly-notif-counter', $counter);
        $this->updateStatus($notification_id, 'sent');

    }

    private function updateToErrorStatus($post_id)
    {
        $this->updateStatus($post_id, 'error');
    }

    private function updateStatus($post_id, $status)
    {
        update_post_meta($post_id, 'leadifly-notif-status', $status);
    }
}