<?php
session_start();
require_once plugin_dir_path(__FILE__) . 'packages/Facebook/autoload.php';

use Facebook\Facebook;
use Facebook\Exceptions\FacebookResponseException;
use Facebook\Exceptions\FacebookSDKException;

$options = get_option('leadifly_options');

if (!isset($options['fb_app_id']) || !isset($options['fb_app_secret'])) {
    wp_die('Missing Facebook credentials');
}

$fb = new Facebook([
    'app_id' => $options['fb_app_id'],
    'app_secret' => $options['fb_app_secret'],
    'default_graph_version' => 'v2.2',
]);

$helper = $fb->getRedirectLoginHelper();

try {
    $accessToken = $helper->getAccessToken(get_site_url() . '/wp-admin/admin-post.php?action=fb_callback');
} catch(FacebookResponseException $e) {
    // When Graph returns an error
    echo 'Graph returned an error: ' . $e->getMessage();
    exit;
} catch(FacebookSDKException $e) {
    // When validation fails or other local issues
    echo 'Facebook SDK returned an error: ' . $e->getMessage();
    exit;
}

if (! isset($accessToken)) {
    if ($helper->getError()) {
        header('HTTP/1.0 401 Unauthorized');
        echo "Error: " . $helper->getError() . "\n";
        echo "Error Code: " . $helper->getErrorCode() . "\n";
        echo "Error Reason: " . $helper->getErrorReason() . "\n";
        echo "Error Description: " . $helper->getErrorDescription() . "\n";
    } else {
        header('HTTP/1.0 400 Bad Request');
        echo 'Bad request';
    }
    exit;
}

$client = $fb->getOAuth2Client();
try {
    // Returns a long-lived access token
    $accessTokenLong = $client->getLongLivedAccessToken($accessToken);
} catch(FacebookSDKException $e) {
    // There was an error communicating with Graph
    echo $e->getMessage();
    exit;
}

try {
    $response = $fb->get('/me?fields=id,name,email,first_name,last_name', $accessToken->getValue());
}  catch(FacebookResponseException $e) {
    echo 'Graph returned an error: ' . $e->getMessage();
    exit;
} catch(FacebookSDKException $e) {
    echo 'Facebook SDK returned an error: ' . $e->getMessage();
    exit;
}

$body = $response->getDecodedBody();

if (!isset($body['email'])) {
    echo 'Please share your email with us.';
    exit;
}

$fbId = $body['id'];
$firstName = $body['first_name'];
$lastName = $body['last_name'];
$email = $body['email'];

// Create new Subscriber if does not exist
require_once plugin_dir_path(__FILE__) . 'class-leadifly-subscribers.php';
$subscriber = new LeadiflySubscribers;

if (!$subscriber->checkIfSubscriberExists($fbId, $email)) {
    $subscriber->create($body, $accessTokenLong);

    if (isset($options['mailchimp_active']) && $options['mailchimp_active']) {
        require_once plugin_dir_path(__FILE__) . 'apis/mailchimp.php';
        $mailchimp = new LeadiflyMailChimp();
        if ($mailchimp->valid == 1) {
            $mailchimp->addSubscriberToList($body);
        }
    }

    if (isset($options['activecampaign_active']) && $options['activecampaign_active']) {
        require_once  plugin_dir_path(__FILE__ ) . 'apis/activecampaign.php';
        $activecampaign = new LeadiflyActivecampaign();
        if ($activecampaign->valid == 1) {
            $activecampaign->addSubscriberToList($body);
        }
    }

    if (isset($options['getresponse_active']) && $options['getresponse_active']) {
        require_once  plugin_dir_path(__FILE__ ) . 'apis/getresponse.php';
        $getresponse = new LeadiflyGetresponse();
        if ($getresponse->valid == 1) {
            $getresponse->addSubscriberToCampaign($body);
        }
    }

    if (isset($options['sendlane_active']) && $options['sendlane_active']) {
        require_once  plugin_dir_path(__FILE__ ) . 'apis/sendlane.php';
        $sendlane = new LeadiflySendlane();
        if ($sendlane->valid == 1) {
            $sendlane->addSubscriberToList($body);
        }
    }

    if (isset($options['aweber_active']) && $options['aweber_active']) {
        require_once plugin_dir_path(__FILE__) . 'apis/aweber.php';
        $aweber = new LeadiflyAweber();
        if ($aweber->valid == 1) {
            $aweber->addSubscriberToList($body);
        }
    }
}


wp_redirect($_SESSION['leadifly-meta-link']);
